@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require_relative 'setup'
+require_relative "setup"
 
 unless Dry::Logic::Rule.respond_to?(:build)
   Dry::Logic::Rule.singleton_class.alias_method(:build, :new)
@@ -18,9 +18,9 @@ comparison = Dry::Logic::Rule.build(predicates[:gteq?]).curry(18)
 
 Benchmark.ips do |x|
   x.report("type check - success") { type_check.(0) }
-  x.report("type check - failure") { type_check.('0') }
+  x.report("type check - failure") { type_check.("0") }
   x.report("int check - success") { int_check.(0) }
-  x.report("int check - failure") { int_check.('0') }
+  x.report("int check - failure") { int_check.("0") }
   x.report("key check - success") { key_check.(with_user) }
   x.report("key check - failure") { key_check.(without_user) }
   x.report("comparison - success") { comparison.(20) }
