@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'dry/core/constants'
-require 'dry/equalizer'
-require 'dry/logic/operators'
+require "dry/core/constants"
+require "dry/core/equalizer"
+require "dry/logic/operators"
 
 module Dry
   module Logic
