@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require 'dry/logic/operations/binary'
-require 'dry/logic/result'
+require "dry/logic/operations/binary"
+require "dry/logic/result"
 
 module Dry
   module Logic
@@ -17,7 +17,7 @@ module Dry
         def type
           :and
         end
-        alias operator type
+        alias_method :operator, :type
 
         def call(input)
           left_result = left.(input)
