@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'dry/logic/operations/abstract'
+require "dry/logic/operations/abstract"
 
 module Dry
   module Logic
@@ -10,9 +10,10 @@ module Dry
 
         attr_reader :right
 
-        def initialize(*rules, **options)
+        def initialize(left, right, **options)
           super
-          @left, @right = rules
+          @left = left
+          @right = right
         end
 
         def ast(input = Undefined)
