@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'dry/logic/operations/unary'
-require 'dry/logic/evaluator'
-require 'dry/logic/result'
+require "dry/logic/operations/unary"
+require "dry/logic/evaluator"
+require "dry/logic/result"
 
 module Dry
   module Logic
@@ -12,7 +12,7 @@ module Dry
 
         def self.new(rule, **options)
           if options[:evaluator]
-            super(rule, options)
+            super(rule, **options)
           else
             keys = options.fetch(:keys)
             evaluator = Evaluator::Set.new(keys)
