@@ -1,24 +1,24 @@
 # frozen_string_literal: true
 
-require 'dry/logic/predicates'
+require "dry/logic/predicates"
 
 RSpec.describe Dry::Logic::Predicates do
-  describe '#false?' do
+  describe "#false?" do
     let(:predicate_name) { :false? }
 
-    context 'when value is false' do
+    context "when value is false" do
       let(:arguments_list) do
         [[false]]
       end
 
-      it_behaves_like 'a passing predicate'
+      it_behaves_like "a passing predicate"
     end
 
-    context 'when value is not false' do
+    context "when value is not false" do
       let(:arguments_list) do
         [
           [true],
-          [''],
+          [""],
           [[]],
           [{}],
           [nil],
@@ -26,12 +26,12 @@ RSpec.describe Dry::Logic::Predicates do
           [String],
           [1],
           [0],
-          ['true'],
-          ['false']
+          ["true"],
+          ["false"]
         ]
       end
 
-      it_behaves_like 'a failing predicate'
+      it_behaves_like "a failing predicate"
     end
   end
 end
