@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
-require 'dry/logic/predicates'
+require "dry/logic/predicates"
 
 RSpec.describe Dry::Logic::Predicates do
-  describe '#number?' do
+  describe "#number?" do
     let(:predicate_name) { :number? }
 
-    context 'when value is numerical' do
+    context "when value is numerical" do
       let(:arguments_list) do
         [
           ["34"],
@@ -18,13 +18,13 @@ RSpec.describe Dry::Logic::Predicates do
         ]
       end
 
-      it_behaves_like 'a passing predicate'
+      it_behaves_like "a passing predicate"
     end
 
-    context 'with value is not numerical' do
+    context "with value is not numerical" do
       let(:arguments_list) do
         [
-          [''],
+          [""],
           ["-14px"],
           ["10,150.00"],
           [nil],
@@ -33,7 +33,7 @@ RSpec.describe Dry::Logic::Predicates do
         ]
       end
 
-      it_behaves_like 'a failing predicate'
+      it_behaves_like "a failing predicate"
     end
   end
 end
