@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
-require 'dry/logic/predicates'
+require "dry/logic/predicates"
 
 RSpec.describe Dry::Logic::Predicates do
-  describe '#respond_to?' do
+  describe "#respond_to?" do
     let(:predicate_name) { :respond_to? }
 
-    context 'when value responds to method' do
+    context "when value responds to method" do
       let(:arguments_list) do
         [
           [:method, Object],
@@ -14,10 +14,10 @@ RSpec.describe Dry::Logic::Predicates do
         ]
       end
 
-      it_behaves_like 'a passing predicate'
+      it_behaves_like "a passing predicate"
     end
 
-    context 'when value does not respond to method' do
+    context "when value does not respond to method" do
       let(:arguments_list) do
         [
           [:foo, Object],
@@ -25,7 +25,7 @@ RSpec.describe Dry::Logic::Predicates do
         ]
       end
 
-      it_behaves_like 'a failing predicate'
+      it_behaves_like "a failing predicate"
     end
   end
 end
