@@ -1,24 +1,24 @@
 # frozen_string_literal: true
 
-require 'dry/logic/predicates'
+require "dry/logic/predicates"
 
 RSpec.describe Dry::Logic::Predicates do
-  describe '#true?' do
+  describe "#true?" do
     let(:predicate_name) { :true? }
 
-    context 'when value is true' do
+    context "when value is true" do
       let(:arguments_list) do
         [[true]]
       end
 
-      it_behaves_like 'a passing predicate'
+      it_behaves_like "a passing predicate"
     end
 
-    context 'with value is not true' do
+    context "with value is not true" do
       let(:arguments_list) do
         [
           [false],
-          [''],
+          [""],
           [[]],
           [{}],
           [nil],
@@ -26,12 +26,12 @@ RSpec.describe Dry::Logic::Predicates do
           [String],
           [1],
           [0],
-          ['true'],
-          ['false']
+          ["true"],
+          ["false"]
         ]
       end
 
-      it_behaves_like 'a failing predicate'
+      it_behaves_like "a failing predicate"
     end
   end
 end
